@@ -5,3 +5,9 @@ from . import find
 
 counties = _meta.courts()
 courts = _meta.courts()
+judges = _meta.judges()
+
+
+type = _meta.get_type
+types = _meta.all_types()
+
